function [] = pickPoint(src, ~)
%PICKPOINT Lets the user pick a point in the plot.
%   Selection can be aborted by using the right mouse button.

global artoaGui artoaWorkspace artoaConfig;

modeName = 'pickPoint';

%% Check for any active mode
if strcmp(artoaGui.editPressure.currentInteractionMode, modeName)
    % pickPoint mode is active, so finish the mode
    closePickPointMode();
    return;
end

if ~islogical(artoaGui.editPressure.currentInteractionMode)
    errordlg('Another interaction mode is currently active. Please finish it first!', 'Interaction mode error!');
    return;
end

%% Check if point is already selected
if ~artoa.controller.edit.pressure.dropSelection()
    return;
end

%% Set mode to pickPoint
openPickPointMode();

%% Initialize variable
artoaGui.editPressure.userSelection = {};
artoaWorkspace.editPressure.userSelection = false(length(artoaWorkspace.pressure), 1);

return

%% Helper functions

    function openPickPointMode()
        pan('off');
        zoom('off');
        brush('off');
        
        artoaGui.editPressure.axesScatterPressure.ButtonDownFcn = @onPick;
        artoaGui.editPressure.scatterPressure.ButtonDownFcn = @onDirectPick;
        artoaGui.editPressure.currentInteractionMode = modeName;
        artoaGui.figures.editPressure.Color = [.6 .6 .6];
        src.String = 'Finish';
        drawnow;
    end

    function closePickPointMode()
        artoaGui.editPressure.axesScatterPressure.ButtonDownFcn = '';
        artoaGui.editPressure.scatterPressure.ButtonDownFcn = '';
        artoaGui.editPressure.currentInteractionMode = false;
        artoaGui.figures.editPressure.Color = [.94 .94 .94];
        src.String = 'Point(s)';
        drawnow;
    end

    function onDirectPick(~, event)
        [x_closest, y_closest, index] = findClosestMatch(event.IntersectionPoint(1), event.IntersectionPoint(2));
        if islogical(index)
            return;
        end
        hold on;
        artoaGui.editPressure.userSelection{end + 1} = scatter( ...
            x_closest, y_closest, ...
            artoaConfig.defaults.pickPointMarkerSize, [1 1 1] ...
            );
        hold off;
        artoaWorkspace.editPressure.userSelection(index) = true;
        src.String = ['Finish ' num2str(sum(artoaWorkspace.editPressure.userSelection)) ' selected'];
    end

    function onPick(~, event)
        [x_closest, y_closest, index] = findClosestMatch( ...
            event.IntersectionPoint(1), event.IntersectionPoint(2) ...
            );
        if islogical(index)
            return;
        end
        hold on;
        artoaGui.editPressure.userSelection{end + 1} = scatter(x_closest, y_closest, artoaConfig.defaults.pickPointMarkerSize, [1 1 1]);
        hold off;
        artoaWorkspace.editPressure.userSelection(index) = true;
        src.String = ['Finish ' num2str(sum(artoaWorkspace.editPressure.userSelection)) ' selected'];
    end

    function [x_closest, y_closest, index] = findClosestMatch(dx, dy, ignoreDeleted)
        if nargin == 2
            ignoreDeleted = false;
        end
        % find closest match
        % calculate distance
        distance = sqrt((artoaWorkspace.rafosDate - dx).^2 + (artoaWorkspace.pressure - dy).^2);
        [~, index] = min(distance);
        x_closest = artoaWorkspace.rafosDate(index);
        y_closest = artoaWorkspace.pressure(index);
        if ~ignoreDeleted & (artoaWorkspace.statusPressure(index) ~= 2)
            return;
        end
        % reset output because the point is deleted
        x_closest = false;
        y_closest = false;
        index = false;
    end

end

