function [] = remapToaToSoundsource(~, ~)
%REMAPTOATOSOUNDSOURCE Remaps the TOAs of the selected soundsource to the new one.
%   Detailed explanation goes here

global artoaWorkspace;

%% Check if soundsources are loaded
if ~artoa.controller.soundSourcesLoaded()
    warndlg('You need to load a soundsource file first!', 'No sound sources loaded');
    return;
end

%% Get all soundsources that have applied toas
soundsourcesWithToa = {};
fnames = fieldnames(artoaWorkspace.filteredSoundsources);
for i = 1:length(fnames)
    currentSoundsource = fnames{i};
    hasToa = artoa.soundsources.hasAppliedToa( ...
        currentSoundsource, ...
        artoaWorkspace.toaData.soundSource ...
        );
    if hasToa
        soundsourcesWithToa{end + 1} = currentSoundsource;
    end
end

%% Check if empty
if isempty(soundsourcesWithToa)
    warndlg('No TOA applied to any soundsource.');
    return;
end

%% Let the user select the sound source to remap

[sourceIndex, success] = listdlg( ...
    'PromptString', 'Select soundsource to remap:',...
    'SelectionMode', 'single',...
    'ListString', soundsourcesWithToa ...
);

if ~success
    return;
end

%% Let the user select the sound source to remap

[destinationIndex, success] = listdlg( ...
    'PromptString', 'Select destination soundsource:',...
    'SelectionMode', 'single',...
    'ListString', fnames ...
);

if ~success
    return;
end

%% Get applied toa of source soundsource
selection = strcmp(soundsourcesWithToa{sourceIndex}, artoaWorkspace.toaData.soundSource);

%% Store
artoaWorkspace.toaData.soundSource(selection) = fnames(destinationIndex);

%% Update duplicate toa table
artoa.controller.edit.timeOfArrival.updateDuplicateToaTable();

%% Update plots
artoa.controller.edit.updateAvailablePlots();

%% Update offsets table and recalculate TOAs
artoa.controller.edit.offsets.tableSoundsourceOffsetsEdit();

%% Update track parameter window if available
artoa.controller.track.parameter.updateGui();


end

