function [ nemo_data ] = data(p_path)
%LOAD_DATA Loads nemo data from the file structure into memory.
%
%   Parameters:
%   p_path:       Absolute or relative filepath to the file structure
%                 containing the nemo data.
%
%   Returns:      Struct, containing loaded nemo data from the text files.

%% Initialize input parameter
nemo_data = false;

%% Parameter check
parameter_error = false;

if (~ischar(p_path))
    warning([mfilename ': Please check input parameter. p_path is not a string!']);
    parameter_error = true;
end

if parameter_error
    return; % return if parameter check has not been passed successfully
else
    clear parameter_error;
end

if (~exist('p_folder_separator', 'var'))
    p_folder_separator = '\';
end

% check if last character is a \
if (~strcmp(p_path(end), p_folder_separator))
    p_path = [p_path p_folder_separator];
end

%% Read profiles

nemo_folder_names = dir(p_path); % get all elements in given directory
folders_to_exclude = {'.', '..'}; % these folders will be excluded from the list
nemo_folder_names = exclude_files(nemo_folder_names);
nemo_folder_names = exclude_elements(nemo_folder_names, folders_to_exclude, 'dir');

%% Loop through every float

files_to_exclude = { ...
    'Startup_Test_Message.profile', ...
    'MTM_Report_Message.profile', ...
    'nemo_0NaN_NaN.profile' ...
    };

if (isempty(nemo_folder_names))
    nemo_data = nemo.load.single_float(p_path, p_folder_separator, files_to_exclude);
    return;
end

nemo_data = {}; % initialize return variable as struct
nemo_data_count = 0;

for o_float_index = 1:length(nemo_folder_names) % every float directory
    % getting the absolute path to the current directory
    current_dir = [p_path nemo_folder_names(o_float_index).name];
    % get all files in it
    current_files = dir(fullfile([current_dir p_folder_separator], '*.profile'));
    current_files = exclude_elements(current_files, files_to_exclude, 'dir');
        
    profile_count = length(current_files);
    
    if (profile_count > 0)
        current_profiles = {};
        
        for o_profile_index = 1:profile_count
            % read current profile
            profile = nemo.profile.load(fullfile([current_dir p_folder_separator], current_files(o_profile_index).name));
            current_profiles{o_profile_index} = profile;
            clear profile;
        end
        
        nemo_data_count = nemo_data_count + 1;
        nemo_data{nemo_data_count} = current_profiles;
        clear current_profiles;
    end
    
end

return

end
