function [ moorings ] = moorings( p_filename )
%LOAD_MOORINGS Loads all moorings from a file into memory
%   Almost the same procedure as nemo.load.config(). It has some changes
%   to make it useful for loading moorings configuration file.

%% Initialize input parameter
moorings = false;

%% Parameter check
parameter_error = false;

if (~ischar(p_filename))
    warning([mfilename ': Please check input parameter. p_filename is not a string!']);
    parameter_error = true;
else
    % get filename details
    if ~exist(p_filename, 'file')
        warning([mfilename ': Please check input parameter, given file does not exist!']);
        parameter_error = true;
    end
end

if parameter_error
    return; % return if parameter check has not been passed successfully
else
    clear parameter_error;
end

%% Load profile into variable

% initialize all required variables
moorings = {};
current_section = '';
comment_char = '%'; % character to indicate comments
section_char = '['; % character indicating new section
mooring_count = 1;

% open file
file_id = fopen(p_filename);
fseek(file_id, 0, 'bof');


% read file line by line
current_line = fgetl(file_id);
while (ischar(current_line))
    if length(current_line) == 0 || strcmp(current_line(1), comment_char)
        current_line = fgetl(file_id);
        continue
    end
    
    switch current_line(1)
        case section_char % this indicates a new section
            current_line = strtrim(current_line);
            current_section = current_line(2:end-1);
            moorings{mooring_count}.name = current_section;
            read_section
            mooring_count = mooring_count + 1;
    end
    %current_line = fgetl(file_id);
end

fclose(file_id);

    function read_section
        % read complete section
        current_line = fgetl(file_id);
        while ischar(current_line) && ~isempty(current_line) ...
                && ~strcmp(current_line(1), section_char)
            
            % ignore comment char
            if strcmp(current_line(1), comment_char)
                current_line = fgetl(file_id);
                continue
            end
            
            % if it contains a comment char anywhere, just take the string
            % before it
            found_comment = strfind(current_line, comment_char);
            if ~isempty(found_comment)
                current_line = current_line(1:found_comment(1)-1);
            end
            
            % get variable name and value
            [token, remain] = strtok(current_line);
            if (strcmp(token(2:end), 'pong_time'))
                moorings{mooring_count}.(token(2:end)) = strtrim(remain);
            else
                % try to convert remain to a number
                remain_as_num = str2num(strtrim(remain));
                if (~isempty(remain_as_num))
                    moorings{mooring_count}.(token(2:end)) = remain_as_num;
                else
                    moorings{mooring_count}.(token(2:end)) = strtrim(remain);
                end
            end
                    
            current_line = fgetl(file_id);
        end
    end


end

