function [ boolean ] = has_status_and_gps( p_profile, p_status )
%HAS_STATUS_AND_GPS Checks if profile has gps coordinates and given status.
%   Checks if the given profile has the given status as well as
%   gps coordinates.
%
%   Returns: True if all conditions are met. Displays a warning if
%   parameters are wrong, but returns false!
%
%   Parameters:
%   p_profile:          The nemo profile that is being checked.
%   p_status:           Expected xmit_upcast_status.

%% Initializing return variables
boolean = false;

%% Parameter check

if (~isstruct(p_profile) ...
        || ~ischar(p_status))
    disp([mfilename ': Wrong parameter. Please check your input. Returning false!']);
end

%% Check status
if (~strcmp(p_status, strtrim(p_profile.xmit_upcast_status)))
    return;
end

%% Check coordinates

if ( ... % one of them is NaN
        isnan(p_profile.gps_lat) ...
        || isnan(p_profile.gps_lon) ...
        )
    return;
end

boolean = true;

return;

end

