function [ resulting_list ] = exclude_elements( p_source, p_exclude_items, p_source_type )
%EXCLUDE_ELEMENTS Excludes items from given source.
%   Runs through the given source and excludes all given elements from it.
%   Currently only source type 'dir' is implemented.
%
%   Parameters:
%   p_source            Input source, class depends on p_source_type.
%   p_exclude_items     Items to exclude from p_source.
%   p_source_type       Type of given source, currently only 'dir' is implemented.

%% Initialize return variables
resulting_list = false;

%% Parameter check
if nargin ~= 3
    warning([mfilename ': Parameter not set correctly! Returning false.']);
    return
end

%% Switch source type

switch p_source_type
    case 'dir'
        tmp_list = [];
        for o_index = 1:length(p_source) % check if element is a directory
            if ~any(strcmp(p_source(o_index).name, p_exclude_items))
                tmp_list = [tmp_list p_source(o_index)];
            end % ignore every other elements
        end
        resulting_list = tmp_list; % copy the created list to the correct variable
        clear tmp_list o_index; % clean up
    otherwise
        warning([mfilename ': Unknown source type! Returning false.']);
        return
end

end

